==> manydhcp2.5.2.tar.bz2: manydhcp/utils/top_sams.php <==
<!DOCTYPE html>
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////

if(empty($title)) $title  = $TEXT['global-title'];
if(empty($description)) $description = $TEXT['global-description'];
$address = "http://".$_SERVER['SERVER_ADDR']."/manydhcp/main.php";
?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="ROBOTS" content="NOINDEX, NOFOLLOW" />
<meta http-equiv="Cache-Control" content="no-cache, must-revalidate" />
<meta name="description" content="<?php echo $description; ?>" />
<title><?php echo $title; ?></title>
<?php
  if(empty($_COOKIE['ident'])) {puterrorclr($TEXT['error-loginform4']); exit();}
  if(strlen($_COOKIE['ident'])>15) {puterrorclr($TEXT['error-login14']); exit();}
  if(empty($_COOKIE['passwrd'])) {puterrorclr($TEXT['error-loginform4']); exit();}
  if(strlen($_COOKIE['passwrd'])>100) {puterrorclr($TEXT['error-login5']); exit();}
  if(!empty($_GET['skin'])) $skin_tmp = $_GET['skin'];
   elseif(!empty($_POST['skin'])) $skin_tmp = $_POST['skin'];
     else $skin_tmp = "base";
?>
<link rel="StyleSheet" type="text/css" href="../skins/<?php echo $skin_tmp; ?>/reader.css" />
<link rel="icon" href="../favicon.ico" type="image/x-icon" />
<link rel="shortcut icon" href="../favicon.ico" type="image/x-icon" />
</head>
<body>
<script type="text/javascript" language="JavaScript" src="../utils/drop_down.js"></script>
<table align="center" width="96%" border="0" cellspacing="0" cellpadding="0">
 <tr>
  <td width="16">&nbsp;</td>
  <td></td>
  <td width="16">&nbsp;</td>
 </tr>
 <tr>
  <td class="osn_top_r"></td>
  <td class="osn_top"></td>
  <td class="osn_top_l"><a href="../logout.php" class=shut_img title="<?php echo $TEXT['global-logout-tit']; ?>"><img class="shut_logo" alt="<?php echo $TEXT['global-logout2']; ?>" src="../skins/base/clr.png"></a></td>
 </tr>
 <tr>
  <td class="osn_left">&nbsp;</td>
  <td class="osn_center">
<table width="100%"  border="0" cellspacing="0" cellpadding="0">
  <tr>
   <td>
    <form action=../addresses/index.php method=post>
<table width="100%"  border="0" cellspacing="0" cellpadding="0">
  <tr>
   <td width="55%">
   <ul id="nav">
	<li><a href="../main.php" class="link" title="<?php echo $TEXT['menu-btn1-title']; ?>"><?php echo $TEXT['menu-btn1']; ?></a>
        </li>
	<li><a href="#null"><?php echo $TEXT['menu-btn20']; ?></a>
	  <ul>
	    <li><a href="#null"><?php echo $TEXT['menu-btn25']; ?></a>
              <ul>
                <li><a class="tooltip3" href="../addresses/index.php" ><?php echo $TEXT['menu-btn15']; ?><span><?php echo $TEXT['menu-btn15-title']; ?><small></small></span></a></li>
                <li><a class="tooltip3" href="../podset/index.php" ><?php echo $TEXT['menu-btn32']; ?><span><?php echo $TEXT['menu-btn132-title']; ?><small></small></span></a></li>
              </ul>
	    </li>
             <li><a class="tooltip3" href="../service/doublefrm.php" ><?php echo $TEXT['menu-btn27']; ?><span><?php echo $TEXT['menu-btn27-title']; ?><small></small></span></a></li>
             <li><a class="tooltip3" href="../logs/index.php" ><?php echo $TEXT['menu-btn5']; ?><span><?php echo $TEXT['menu-btn5-title']; ?><small></small></span></a></li>
             <li><a class="tooltip3" href="../logins/index.php" c"><?php echo $TEXT['menu-btn7']; ?><span><?php echo $TEXT['menu-btn7-title']; ?><small></small></span></a></li>
	   </ul>
	</li>
      </ul>
</td>
 <td align="right"><input class="inputsearch" size="30" maxlength="50" type=text name=search title="<?php echo $TEXT['search-btn-title']; ?>" >&nbsp;<input type=submit class="button" value='<?php echo $TEXT['search-btn']; ?>'></td>
</tr>
</table>
<hr size="1" width="99%" />
  <table width="100%"  border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td align="left" class="bold_it"><?php echo $TEXT['global-hellow']; ?><?php echo $_GET['descr_usr']; ?></td>
     <td align="right" class="menu">
       <input type=radio name=typepar value=5 checked><?php echo $TEXT['search-skv']; ?>
       <input type=radio name=typepar value=1><?php echo $TEXT['search-ip']; ?>
       <input type=radio name=typepar value=2><?php echo $TEXT['search-mac']; ?>
       <input type=radio name=typepar value=4><?php echo $TEXT['addr-name']; ?>
       <input type=radio name=typepar value=3><?php echo $TEXT['addr-descr']; ?>
     </td>
    </tr>
   </table>
  <hr size="3" width="98%" />
</form>
  <tr>
   <td>

==> manydhcp2.7.2.tar.bz2: manydhcp/utils/top_sams.php <==
<!DOCTYPE html>
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////

if(empty($title)) {$title = $TEXT['global-title'];}
if(empty($description)) {$description = $TEXT['global-description'];}
$address = "http://".$_SERVER['SERVER_ADDR']."/manydhcp/main.php";
?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="ROBOTS" content="NOINDEX, NOFOLLOW" />
<meta http-equiv="Cache-Control" content="no-cache, must-revalidate" />
<meta name="description" content="<?php echo $description; ?>" />
<title><?php echo $title; ?></title>
<?php
  if(empty($_COOKIE['ident'])) {puterrorclr($TEXT['error-loginform4']); exit();}
  if(strlen($_COOKIE['ident'])>15) {puterrorclr($TEXT['error-login14']); exit();}
  if(empty($_COOKIE['passwrd'])) {puterrorclr($TEXT['error-loginform4']); exit();}
  if(strlen($_COOKIE['passwrd'])>100) {puterrorclr($TEXT['error-login5']); exit();}
  if(!empty($_GET['skin'])) {$skin_tmp = $_GET['skin'];}
   elseif(!empty($_POST['skin'])) {$skin_tmp = $_POST['skin'];}
     else {$skin_tmp = "base";}
?>
<link rel="StyleSheet" type="text/css" href="../skins/<?php echo $skin_tmp; ?>/reader.css" />
<link rel="icon" href="../favicon.ico" type="image/x-icon" />
<link rel="shortcut icon" href="../favicon.ico" type="image/x-icon" />
</head>
<body>
<script type="text/javascript" language="JavaScript" src="../utils/drop_down.js"></script>
<table align="center" width="96%" border="0" cellspacing="0" cellpadding="0">
 <tr>
  <td width="16">&nbsp;</td>
  <td></td>
  <td width="16">&nbsp;</td>
 </tr>
 <tr>
  <td class="osn_top_r"></td>
  <td class="osn_top"></td>
  <td class="osn_top_l"><a href="../logout.php" class=shut_img title="<?php echo $TEXT['global-logout-tit']; ?>"><img class="shut_logo" alt="<?php echo $TEXT['global-logout2']; ?>" src="../skins/base/clr.png"></a></td>
 </tr>
 <tr>
  <td class="osn_left">&nbsp;</td>
  <td class="osn_center">
<table width="100%"  border="0" cellspacing="0" cellpadding="0">
  <tr>
   <td>
    <form action=../addresses/index.php method=post>
<table width="100%"  border="0" cellspacing="0" cellpadding="0">
  <tr>
   <td width="55%">
   <ul id="nav">
	<li><a href="../main.php" class="link" title="<?php echo $TEXT['menu-btn1-title']; ?>"><?php echo $TEXT['menu-btn1']; ?></a>
        </li>
	<li><a href="#null"><?php echo $TEXT['menu-btn20']; ?></a>
	  <ul>
	    <li><a href="#null"><?php echo $TEXT['menu-btn25']; ?></a>
              <ul>
                <li><a class="tooltip3" href="../addresses/index.php" ><?php echo $TEXT['menu-btn15']; ?><span><?php echo $TEXT['menu-btn15-title']; ?><small></small></span></a></li>
                <li><a class="tooltip3" href="../podset/index.php" ><?php echo $TEXT['menu-btn32']; ?><span><?php echo $TEXT['menu-btn132-title']; ?><small></small></span></a></li>
              </ul>
	    </li>
             <li><a class="tooltip3" href="../service/doublefrm.php" ><?php echo $TEXT['menu-btn27']; ?><span><?php echo $TEXT['menu-btn27-title']; ?><small></small></span></a></li>
             <li><a class="tooltip3" href="../logs/index.php" ><?php echo $TEXT['menu-btn5']; ?><span><?php echo $TEXT['menu-btn5-title']; ?><small></small></span></a></li>
             <li><a class="tooltip3" href="../logins/index.php" c"><?php echo $TEXT['menu-btn7']; ?><span><?php echo $TEXT['menu-btn7-title']; ?><small></small></span></a></li>
	   </ul>
	</li>
      </ul>
</td>
 <td align="right"><input class="inputsearch" size="30" maxlength="50" type=text name=search title="<?php echo $TEXT['search-btn-title']; ?>" >&nbsp;<input type=submit class="button" value='<?php echo $TEXT['search-btn']; ?>'></td>
</tr>
</table>
<hr size="1" width="99%" />
  <table width="100%"  border="0" cellspacing="0" cellpadding="0">
    <tr>
     <td align="left" class="bold_it"><?php echo $TEXT['global-hellow']; ?><?php echo $_GET['descr_usr']; ?></td>
     <td align="right" class="menu">
       <input type=radio name=typepar value=5 checked><?php echo $TEXT['search-skv']; ?>
       <input type=radio name=typepar value=1><?php echo $TEXT['search-ip']; ?>
       <input type=radio name=typepar value=2><?php echo $TEXT['search-mac']; ?>
       <input type=radio name=typepar value=4><?php echo $TEXT['addr-name']; ?>
       <input type=radio name=typepar value=3><?php echo $TEXT['addr-descr']; ?>
     </td>
    </tr>
   </table>
  <hr size="3" width="98%" />
</form>
  <tr>
   <td>
